@@ -202,7 +202,7 @@ HMAT_API hmat_clustering_algorithm_t* hmat_create_clustering_max_dof(const hmat_
  * delegate to an other algorithm.
  * @param algo the delegate algorithm
  * @param ratio ratio between the number of DOF in a cluster and
- * a span size so a DOF is concidered as large
+ * a span size so a DOF is considered as large
  */
 HMAT_API hmat_clustering_algorithm_t* hmat_create_clustering_span(
         const hmat_clustering_algorithm_t* algo, double ratio);
@@ -250,6 +250,8 @@ HMAT_API void hmat_delete_cluster_tree(const hmat_cluster_tree_t * tree);
 
 HMAT_API hmat_cluster_tree_t * hmat_copy_cluster_tree(const hmat_cluster_tree_t * tree);
 
+HMAT_API void hmat_swap_cluster_tree(hmat_cluster_tree_t *first, hmat_cluster_tree_t *second);
+
 struct hmat_cluster_tree_create_context_t {
     /** Spatial dimension */
     unsigned dimension;
@@ -609,6 +611,40 @@ struct hmat_get_values_context_t {
     int renumber_rows:1;
 };
 
+/**
+ * Argument of the solve_generic function.
+ */
+struct hmat_solve_context_t {
+    /**
+     * RHS on input and solution on output.
+     * Can be either an hmat_matrix_t or a dense array.
+     */
+    void* values;
+
+    /** If 0, values is an hmatrix.  Otherwise, number of right hand sides */
+    int nr_rhs;
+
+    /** When input is a dense array, rows must be permuted to have the same numbering as column dofs.
+     * If this permutation had already been made, no_permutation must be set.
+     */
+    int no_permutation;
+
+    /** If true, solve L X = B; default is to solve A X = B.
+     * @warning lower and upper cannot be both set.
+     */
+    int lower;
+
+    /** If true, solve U X = B; default is to solve A X = B.
+     * @warning lower and upper cannot be both set.
+     */
+    int upper;
+
+    /** Not used, may be useful later. */
+    hmat_progress_t * progress;
+};
+
+HMAT_API void hmat_solve_context_init(struct hmat_solve_context_t * context);
+
 /* Opaque pointer */
 typedef struct
 {
@@ -721,6 +757,14 @@ typedef struct
     */
     int (*destroy_child)(hmat_matrix_t* hmatrix);
 
+    /*! \brief Solve A X = B, with X overwriting B.
+
+      \param hmatrix
+      \param context
+      \return 0 for success
+    */
+    int (*solve_generic)(hmat_matrix_t* matrix, const struct hmat_solve_context_t * context);
+
     /*! \brief Solve A X = B, with X overwriting B.
 
       In this function, B is a H-matrix
@@ -987,6 +1031,14 @@ typedef struct
      * reporting.
      */
     void (*set_progressbar)(hmat_matrix_t * matrix, hmat_progress_t * progress);
+    /**
+     * @brief Extract matrix diagonal_block
+     * \param hmatrix A hmatrix
+     * \param components  extract each (components x components) block
+     * \param diag allocated memory area in which diagonal values are written
+     */
+    int (*extract_diagonal_block)(hmat_matrix_t* holder, int components, void* diag);
+
 }  hmat_interface_t;
 
 HMAT_API void hmat_init_default_interface(hmat_interface_t * i, hmat_value_t type);
