@@ -158,6 +158,10 @@ hmat_cluster_tree_t * hmat_copy_cluster_tree(const hmat_cluster_tree_t * tree) {
         reinterpret_cast<const ClusterTree*>(tree)->copy());
 }
 
+void hmat_swap_cluster_tree(hmat_cluster_tree_t *first, hmat_cluster_tree_t *second) {
+  reinterpret_cast<ClusterTree*>(first)->swap(reinterpret_cast<ClusterTree*>(second));
+}
+
 int hmat_tree_nodes_count(const hmat_cluster_tree_t * tree)
 {
     return ((ClusterTree*)tree)->nodesCount();
@@ -311,6 +315,11 @@ void hmat_factorization_context_init(hmat_factorization_context_t *context) {
     context->progress = DefaultProgress::getInstance();
 }
 
+void hmat_solve_context_init(hmat_solve_context_t * context) {
+    memset(context, 0, sizeof(*context));
+    context->progress = DefaultProgress::getInstance();
+}
+
 void hmat_delete_procedure(hmat_procedure_t* proc) {
     switch (proc->value_type) {
     case HMAT_SIMPLE_PRECISION: delete static_cast<hmat::TreeProcedure<HMatrix<S_t> >*>(proc->internal); break;
