@@ -500,45 +500,74 @@ int vector_restore(void* vec_b, const hmat_cluster_tree_t *rows_ct, int rows, co
 }
 
 template<typename T, template <typename> class E>
-int solve_mat(hmat_matrix_t* hmat, hmat_matrix_t* hmatB) {
+int solve_generic(hmat_matrix_t* holder, const struct hmat_solve_context_t* context) {
+  HMAT_ASSERT_MSG(!(context->lower && context->upper),
+                  "lower and upper cannot both be true in hmat_solve_context_t");
   DECLARE_CONTEXT;
+  hmat::HMatInterface<T>* hmat = (hmat::HMatInterface<T>*)holder;
+  // Solve functions do not receive a progress bar as argument, they use the one
+  // stored in HMatInterface.  Temporarily modify progress bar.
+  hmat_progress_t * saved_progress = hmat->engine().progress();
+  hmat->progress(context->progress);
   try {
-      ((hmat::HMatInterface<T>*)hmat)->solve(*(hmat::HMatInterface<T>*)hmatB);
+      if (context->nr_rhs == 0) {
+          // B is an HMatrix
+          hmat::HMatInterface<T>* hmatB = (hmat::HMatInterface<T>*)context->values;
+          if (context->lower)
+              hmat->solveLower(*hmatB, false);
+          else if (context->upper)
+              hmat->solveLower(*hmatB, true);
+          else
+              hmat->solve(*hmatB);
+      } else {
+          hmat::ScalarArray<T> mb((T*)context->values, hmat->cols()->size(), context->nr_rhs);
+          if (!context->no_permutation)
+              hmat::reorderVector<T>(&mb, context->upper ? hmat->rows()->indices() : hmat->cols()->indices(), 0);
+          if (context->lower)
+              hmat->solveLower(mb, false);
+          else if (context->upper)
+              hmat->solveLower(mb, true);
+          else
+              hmat->solve(mb);
+          if (!context->no_permutation)
+              hmat::restoreVectorOrder<T>(&mb, context->upper ? hmat->rows()->indices() : hmat->cols()->indices(), 0);
+      }
   } catch (const std::exception& e) {
       fprintf(stderr, "%s\n", e.what());
+      // Restore progress bar
+      hmat->progress(saved_progress);
       return 1;
   }
+  // Restore progress bar
+  hmat->progress(saved_progress);
   return 0;
 }
 
+template<typename T, template <typename> class E>
+int solve_mat(hmat_matrix_t* holder, hmat_matrix_t* hmatB) {
+  struct hmat_solve_context_t ctx;
+  hmat_solve_context_init(&ctx);
+  ctx.values = hmatB;
+  return solve_generic<T, E>(holder, &ctx);
+}
+
 template<typename T, template <typename> class E>
 int solve_systems(hmat_matrix_t* holder, void* b, int nrhs) {
-  DECLARE_CONTEXT;
-  hmat::HMatInterface<T>* hmat = (hmat::HMatInterface<T>*)holder;
-  try {
-      hmat::ScalarArray<T> mb((T*) b, hmat->cols()->size(), nrhs);
-      hmat::reorderVector<T>(&mb, hmat->cols()->indices(), 0);
-      hmat->solve(mb);
-      hmat::restoreVectorOrder<T>(&mb, hmat->cols()->indices(), 0);
-  } catch (const std::exception& e) {
-      fprintf(stderr, "%s\n", e.what());
-      return 1;
-  }
-  return 0;
+  struct hmat_solve_context_t ctx;
+  hmat_solve_context_init(&ctx);
+  ctx.values = b;
+  ctx.nr_rhs = nrhs;
+  return solve_generic<T, E>(holder, &ctx);
 }
 
 template<typename T, template <typename> class E>
 int solve_dense(hmat_matrix_t* holder, void* b, int nrhs) {
-  DECLARE_CONTEXT;
-  hmat::HMatInterface<T>* hmat = (hmat::HMatInterface<T>*)holder;
-  try {
-      hmat::ScalarArray<T> mb((T*) b, hmat->cols()->size(), nrhs);
-      hmat->solve(mb);
-  } catch (const std::exception& e) {
-      fprintf(stderr, "%s\n", e.what());
-      return 1;
-  }
-  return 0;
+  struct hmat_solve_context_t ctx;
+  hmat_solve_context_init(&ctx);
+  ctx.values = b;
+  ctx.nr_rhs = nrhs;
+  ctx.no_permutation = 1;
+  return solve_generic<T, E>(holder, &ctx);
 }
 
 template<typename T, template <typename> class E>
@@ -646,21 +675,14 @@ int extract_diagonal(hmat_matrix_t* holder, void* diag, int size)
 }
 
 template<typename T, template <typename> class E>
-int solve_lower_triangular(hmat_matrix_t* holder, int transpose, void* b, int nrhs)
+int extract_diagonal_block(hmat_matrix_t* holder, int components, void* diag)
 {
   DECLARE_CONTEXT;
-  hmat::HMatInterface<T>* hmat = (hmat::HMatInterface<T>*)holder;
-  hmat::ScalarArray<T> mb((T*) b, hmat->cols()->size(), nrhs);
+  hmat::HMatInterface<T>* hmat = (hmat::HMatInterface<T>*) holder;
   try {
-      if (transpose)
-        hmat::reorderVector<T>(&mb, hmat->rows()->indices(), 0);
-      else
-        hmat::reorderVector<T>(&mb, hmat->cols()->indices(), 0);
-      hmat->solveLower(mb, transpose);
-      if (transpose)
-        hmat::restoreVectorOrder<T>(&mb, hmat->rows()->indices(), 0);
-      else
-        hmat::restoreVectorOrder<T>(&mb, hmat->cols()->indices(), 0);
+      hmat->engine().hmat->extractDiagonal(static_cast<T*>(diag), components);
+      hmat::ScalarArray<T> permutedDiagonal(static_cast<T*>(diag), components, hmat->cols()->size());
+      hmat::restoreVectorOrder(&permutedDiagonal, hmat->cols()->indices(), 1);
   } catch (const std::exception& e) {
       fprintf(stderr, "%s\n", e.what());
       return 1;
@@ -668,19 +690,33 @@ int solve_lower_triangular(hmat_matrix_t* holder, int transpose, void* b, int nr
   return 0;
 }
 
+template<typename T, template <typename> class E>
+int solve_lower_triangular(hmat_matrix_t* holder, int transpose, void* b, int nrhs)
+{
+  struct hmat_solve_context_t ctx;
+  hmat_solve_context_init(&ctx);
+  ctx.values = b;
+  ctx.nr_rhs = nrhs;
+  if (transpose)
+     ctx.upper = 1;
+  else
+     ctx.lower = 1;
+  return solve_generic<T, E>(holder, &ctx);
+}
+
 template<typename T, template <typename> class E>
 int solve_lower_triangular_dense(hmat_matrix_t* holder, int transpose, void* b, int nrhs)
 {
-  DECLARE_CONTEXT;
-  hmat::HMatInterface<T>* hmat = (hmat::HMatInterface<T>*)holder;
-  hmat::ScalarArray<T> mb((T*) b, hmat->cols()->size(), nrhs);
-  try {
-      hmat->solveLower(mb, transpose);
-  } catch (const std::exception& e) {
-      fprintf(stderr, "%s\n", e.what());
-      return 1;
-  }
-  return 0;
+  struct hmat_solve_context_t ctx;
+  hmat_solve_context_init(&ctx);
+  ctx.values = b;
+  ctx.nr_rhs = nrhs;
+  ctx.no_permutation = 1;
+  if (transpose)
+     ctx.upper = 1;
+  else
+     ctx.lower = 1;
+  return solve_generic<T, E>(holder, &ctx);
 }
 
 template <typename T, template <typename> class E>
@@ -840,6 +876,7 @@ static void createCInterface(hmat_interface_t * i)
     i->norm = norm<T, E>;
     i->logdet = logdet<T, E>;
     i->scale = scale<T, E>;
+    i->solve_generic = solve_generic<T, E>;
     i->solve_mat = solve_mat<T, E>;
     i->solve_systems = solve_systems<T, E>;
     i->solve_dense = solve_dense<T, E>;
@@ -852,6 +889,7 @@ static void createCInterface(hmat_interface_t * i)
     i->own_cluster_trees = own_cluster_trees<T, E>;
     i->set_low_rank_epsilon = set_low_rank_epsilon<T, E>;
     i->extract_diagonal = extract_diagonal<T, E>;
+    i->extract_diagonal_block = extract_diagonal_block<T, E>;
     i->solve_lower_triangular = solve_lower_triangular<T, E>;
     i->solve_lower_triangular_dense = solve_lower_triangular_dense<T, E>;
     i->assemble_generic = assemble_generic<T, E>;
