@@ -44,18 +44,6 @@
 #include "cluster_assembly_function.hpp"
 #include "random_pivot_manager.hpp"
 
-#ifdef _MSC_VER
-// Intel compiler defines isnan in global namespace
-// MSVC defines _isnan
-# ifndef __INTEL_COMPILER
-#  define isnan _isnan
-# endif
-#elif __GLIBC__ == 2 && __GLIBC_MINOR__ < 23
-// https://sourceware.org/bugzilla/show_bug.cgi?id=19439
-#elif __cplusplus >= 201103L || !defined(__GLIBC__)
-using std::isnan;
-#endif
-
 using std::vector;
 using std::min;
 using std::max;
@@ -306,6 +294,7 @@ void acaFull(ScalarArray<T> & m, ScalarArray<T>* & tmpA, ScalarArray<T>* & tmpB,
 
       // performs the rank 1 operation m := m - va_nu*vb_nu^T
       // in order to nullify m->get(i_nu, j_nu) (the previous maximum value)
+      // as well as the whole row i_nu and column j_nu
       m.rankOneUpdate(-1, va_nu, vb_nu);
 
       // Update the estimate norm
@@ -442,7 +431,7 @@ doCompressionAcaPartial(const ClusterAssemblyFunction<T>& block, double compress
       delete bCol;
       // We look for another row which has not already been used.
       row_index = 0;
-      while (!rowFree[row_index]) {
+      while (row_index < rowCount && !rowFree[row_index]) {
         row_index++;
       }
     } else {
@@ -764,7 +753,7 @@ template<typename T> RkMatrix<typename Types<T>::dp>* compressOneStratum(
 
     // If I meet a NaN, I save & leave
     // TODO : improve this behaviour
-    if (isnan(approxNorm)) {
+    if (!swIsFinite(approxNorm)) {
       rkFull->toFile("Rk");
       full->toFile("Full");
       HMAT_ASSERT(false);
