@@ -78,7 +78,7 @@ void HMatInterface<T>::factorize(Factorization t, hmat_progress_t * progress) {
   if(progress != NULL)
     progress->max = engine_->hmat->rows()->size();
   engine_->factorization(t);
-  factorizationType = t;
+  factorizationType = t; // used by the solve() methods
   engine_->hmat->checkStructure();
 }
 
@@ -190,6 +190,13 @@ void HMatInterface<T>::solveLower(ScalarArray<T>& b, bool transpose) const {
   engine_->solveLower(b, factorizationType, transpose);
 }
 
+template<typename T>
+void HMatInterface<T>::solveLower(HMatInterface<T>& b, bool transpose) const {
+  DISABLE_THREADING_IN_BLOCK;
+  DECLARE_CONTEXT;
+  engine_->solveLower(*b.engine_, factorizationType, transpose);
+}
+
 template<typename T>
 HMatInterface<T>* HMatInterface<T>::copy(bool structOnly) const {
   DECLARE_CONTEXT;
