@@ -612,7 +612,7 @@ template<typename T, typename std::enable_if<hmat::Types<T>::IS_REAL::value, T*>
 void checkNanSFINAE(const ScalarArray<T>* m) {
   for (int col = 0; col < m->cols; col++) {
     for (int row = 0; row < m->rows; row++) {
-      HMAT_ASSERT(std::isfinite(m->get(row, col)));
+      HMAT_ASSERT(swIsFinite(m->get(row, col)));
     }
   }
 }
@@ -621,8 +621,8 @@ template<typename T, typename std::enable_if<!hmat::Types<T>::IS_REAL::value, T*
 void checkNanSFINAE(const ScalarArray<T>* m) {
   for (int col = 0; col < m->cols; col++) {
     for (int row = 0; row < m->rows; row++) {
-      HMAT_ASSERT(std::isfinite(m->get(row, col).real()));
-      HMAT_ASSERT(std::isfinite(m->get(row, col).imag()));
+      HMAT_ASSERT(swIsFinite(m->get(row, col).real()));
+      HMAT_ASSERT(swIsFinite(m->get(row, col).imag()));
     }
   }
 }
@@ -1328,7 +1328,7 @@ template<typename T> int ScalarArray<T>::modifiedGramSchmidt(ScalarArray<T> *res
       pivmax = norm2_update[pivot];
       relative_epsilon = prec * prec;
     }
-    if (j<initialPivot) {
+    if (j<initialPivot) { // is it possible ?
       pivot = j;
       pivmax = 1.;
     }
@@ -1363,7 +1363,7 @@ template<typename T> int ScalarArray<T>::modifiedGramSchmidt(ScalarArray<T> *res
 
       // Remove the qj-component from vectors bk (k=j+1,...,n-1)
       if (j<cols-1) {
-        int firstcol=std::max(j+1, initialPivot) ;
+        int firstcol=std::max(j+1, initialPivot) ; // should always be j+1, no ?
         ScalarArray<T> bK(*this, 0, rows, firstcol, cols-firstcol); // All the columns of 'this' after column 'firstcol'
         ScalarArray<T> aj_bK(r, j, 1, firstcol, cols-firstcol); // In 'r': row 'j', all the columns after column 'firstcol'
         // Compute in 1 operation all the scalar products between aj and a_firstcol, ..., a_n
